import {
  select,csv,scaleLinear,scaleTime,extent,axisLeft,axisBottom,line,max
} from 'd3';

const svg = select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');
const render = data => { 
const title = 'Car prices from 2009 to 2018 in USA';
const xValue = d => d.Year; //display dates on x axis
const xAxisLabel = 'Year';

  const yValue = d => d.Sales; //display salees value on y axis
  const yAxisLabel = 'Price';
  
  const margin = { top: 60, right: 40, bottom: 88, left: 150 };
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  const g = svg.append('g')
    .attr('transform', `translate(${margin.left},${margin.top})`);
  const xScale = scaleTime()
    .domain(extent(data, xValue)) 
    .range([0, innerWidth])
    .nice();
  const xAxis = axisBottom(xScale)
    .tickSize(-innerHeight)
    .tickPadding(15);
  const yScale = scaleLinear()
    .domain([0, max(data, yValue )])
    .range([innerHeight, 0])
    .nice();

  const yAxis = axisLeft(yScale)
    .tickSize(-innerWidth)
    .tickPadding(10);

  const yAxisG = g.append('g').call(yAxis);
  	yAxisG.selectAll('.domain').remove();
  	yAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', -90)
      .attr('x', -innerHeight / 3)
      .attr('fill', 'black')
      .attr('transform', `rotate(-90)`)
      .text(yAxisLabel);

  const xAxisG = g.append('g').call(xAxis)
    	.attr('transform', `translate(0,${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
      .attr('class', 'axis-label')
      .attr('y', 70)
      .attr('x', innerWidth / 2)
      .attr('fill', 'black')
      .text(xAxisLabel);

  const lineGenerator = line()
  	.x(d => xScale(xValue(d)))
  	.y(d => yScale(yValue(d)));
  g.append('path')
  	.attr('class', 'line_path')
  	.attr('d', lineGenerator(data))

  g.append('text')
      .attr('class', 'title')
      .attr('y', -10)
      .text(title);
};

csv('https://gist.githubusercontent.com/pethavenu/af3ff49df9946857d57aef22d1e7a7d6/raw/684d1ff57bac54a2998ccfc25665a794600a47f4/cardata.csv')
  .then(data => {
 
    data.forEach(d => {
    	d.Sales = +d.Sales;
      d.Year = new Date(d.Year)
    });
    render(data);
  });